@@ -27,22 +27,27 @@ def get_default_root(what=None):
 
 def apply_class_bindings(window: tkinter.Widget):
     """Add class level event bindings in application"""
-    for className in ["TEntry", "TSpinbox", "TCombobox"]:
+    for className in ["TEntry", "TSpinbox", "TCombobox", "Text"]:
         window.bind_class(
             className=className, 
             sequence="<Configure>", 
             func=on_disabled_readonly_state,
-            add="+"
-        )
+            add="+")
 
         for sequence in ["<Control-a>", "<Control-A>"]:
             window.bind_class(
                 className=className, 
                 sequence=sequence,
-                func=on_select_all
-        )
+                func=on_select_all)
+
     window.unbind_class("TButton", "<Key-space>")
-    window.bind_class("TButton", "<Key-Return>", lambda event: event.widget.invoke())
+
+    def on_button_enter(event):
+        widget = window.nametowidget(event.widget)
+        widget.invoke()
+
+    window.bind_class("TButton", "<Key-Return>", on_button_enter)
+    window.bind_class("TButton", "<KP_Enter>", on_button_enter)
 
 
 def apply_all_bindings(window: tkinter.Widget):
@@ -90,8 +95,13 @@ def on_select_all(event):
     """Callback to select all text in the input widget when an event is
     executed."""
     widget = event.widget
-    widget.select_range(0, END)
-    widget.icursor(END)
+    if widget.__class__.__name__ == "Text":
+        widget.tag_add(SEL, "1.0", END)
+        widget.mark_set(INSERT, END)
+        widget.see(END)
+    else:
+        widget.select_range(0, END)
+        widget.icursor(END)
     return 'break'    
 
 
